@@ -47,8 +47,8 @@ def ext_bars_test():
     # frequency = TDXParams.KLINE_TYPE_15MIN
     frequency = INTERVAL_TDX_MAP[Interval.MINUTE]
 
-    symbol = "RBL8"
-    market = TdxMarket.SHFE
+    symbol = "AL8"
+    market = TdxMarket.DCE
 
     start = 0
     offset = 1000  # max value is 700
